@@ -182,6 +182,21 @@ Row<eT>::operator=(const std::vector<eT>& x)
 
 
 
+template<typename eT>
+inline
+Row<eT>::Row(const SpRow<eT>& X)
+  : Mat<eT>(arma_vec_indicator(), 1, X.n_elem, 1)
+  {
+  arma_extra_debug_sigprint_this(this);
+
+  arrayops::inplace_set(Mat<eT>::memptr(), eT(0), X.n_elem);
+
+  for(typename SpRow<eT>::const_iterator it = X.begin(); it != X.end(); ++it)
+    at(it.col()) = (*it);
+  }
+
+
+
 template<typename eT>
 inline
 const Row<eT>&
