@@ -1,8 +1,5 @@
-// Copyright (C) 2010 NICTA and the authors listed below
-// http://nicta.com.au
-// 
-// Authors:
-// - Conrad Sanderson (conradsand at ieee dot org)
+// Copyright (C) 2008-2012 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2012 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -22,9 +19,10 @@ class access
   {
   public:
   
-  //! internal function to allow modification of data declared as read-only
-  template<typename T1> arma_inline static T1& rw(const T1& x) { return const_cast<T1&>(x); }
-
+  //! internal function to allow modification of data declared as read-only (use with caution)
+  template<typename T1> arma_inline static T1&  rw (const T1& x)        { return const_cast<T1& >(x); }
+  template<typename T1> arma_inline static T1*& rwp(const T1* const& x) { return const_cast<T1*&>(x); }
+  
   //! internal function to obtain the real part of either a plain number or a complex number
   template<typename eT> arma_inline static const eT& tmp_real(const eT&              X) { return X;        }
   template<typename  T> arma_inline static const   T tmp_real(const std::complex<T>& X) { return X.real(); }
