@@ -292,7 +292,7 @@ conv_to< Row<out_eT> >::from(const Base<in_eT, T1>& in, const typename arma_not_
   const unwrap<T1>      tmp(in.get_ref());
   const Mat<in_eT>& X = tmp.M;
   
-  arma_debug_check( (X.is_vec() == false), "conv_to(): given object can't be interpreted as a vector" );
+  arma_debug_check( ( (X.is_vec() == false) && (X.is_empty() == false) ), "conv_to(): given object can't be interpreted as a vector" );
   
   Row<out_eT> out(X.n_elem);
   
@@ -315,7 +315,7 @@ conv_to< Row<out_eT> >::from(const Base<in_eT, T1>& in, const typename arma_cx_o
   const unwrap<T1>      tmp(in.get_ref());
   const Mat<in_eT>& X = tmp.M;
   
-  arma_debug_check( (X.is_vec() == false), "conv_to(): given object can't be interpreted as a vector" );
+  arma_debug_check( ( (X.is_vec() == false) && (X.is_empty() == false) ), "conv_to(): given object can't be interpreted as a vector" );
   
   Row<out_eT> out(X.n_rows, X.n_cols);
   
@@ -423,7 +423,7 @@ conv_to< Col<out_eT> >::from(const Base<in_eT, T1>& in, const typename arma_not_
   const unwrap<T1>      tmp(in.get_ref());
   const Mat<in_eT>& X = tmp.M;
   
-  arma_debug_check( (X.is_vec() == false), "conv_to(): given object can't be interpreted as a vector" );
+  arma_debug_check( ( (X.is_vec() == false) && (X.is_empty() == false) ), "conv_to(): given object can't be interpreted as a vector" );
   
   Col<out_eT> out(X.n_elem);
   
@@ -446,7 +446,7 @@ conv_to< Col<out_eT> >::from(const Base<in_eT, T1>& in, const typename arma_cx_o
   const unwrap<T1>      tmp(in.get_ref());
   const Mat<in_eT>& X = tmp.M;
   
-  arma_debug_check( (X.is_vec() == false), "conv_to(): given object can't be interpreted as a vector" );
+  arma_debug_check( ( (X.is_vec() == false) && (X.is_empty() == false) ), "conv_to(): given object can't be interpreted as a vector" );
   
   Col<out_eT> out(X.n_rows, X.n_cols);
   
@@ -603,7 +603,7 @@ conv_to< std::vector<out_eT> >::from(const Base<in_eT, T1>& in, const typename a
   const unwrap<T1>      tmp(in.get_ref());
   const Mat<in_eT>& X = tmp.M;
   
-  arma_debug_check( (X.is_vec() == false), "conv_to(): given object can't be interpreted as a vector" );
+  arma_debug_check( ( (X.is_vec() == false) && (X.is_empty() == false) ), "conv_to(): given object can't be interpreted as a vector" );
   
   const uword N = X.n_elem;
   
@@ -637,7 +637,7 @@ conv_to< std::vector<out_eT> >::from(const Base<in_eT, T1>& in, const typename a
   const unwrap<T1>      tmp(in.get_ref());
   const Mat<in_eT>& X = tmp.M;
   
-  arma_debug_check( (X.is_vec() == false), "conv_to(): given object can't be interpreted as a vector" );
+  arma_debug_check( ( (X.is_vec() == false) && (X.is_empty() == false) ), "conv_to(): given object can't be interpreted as a vector" );
   
   std::vector<out_eT> out(X.n_elem);
   
