@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2012 NICTA (www.nicta.com.au)
-// Copyright (C) 2008-2012 Conrad Sanderson
+// Copyright (C) 2008-2013 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2013 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -54,16 +54,67 @@ det
   
   const diagmat_proxy<T1> A(X.m);
   
-  const uword A_n_elem = A.n_elem;
+  const uword N = A.n_elem;
   
-  eT val = eT(1);
+  eT val1 = eT(1);
+  eT val2 = eT(1);
   
-  for(uword i=0; i<A_n_elem; ++i)
+  uword i,j;
+  for(i=0, j=1; j<N; i+=2, j+=2)
     {
-    val *= A[i];
+    val1 *= A[i];
+    val2 *= A[j];
     }
   
-  return val;
+  
+  if(i < N)
+    {
+    val1 *= A[i];
+    }
+  
+  return val1 * val2;
+  }
+
+
+
+//! determinant of a triangular matrix
+template<typename T1>
+inline
+arma_warn_unused
+typename T1::elem_type
+det
+  (
+  const Op<T1, op_trimat>& X,
+  const bool slow = false
+  )
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(slow);
+  
+  typedef typename T1::elem_type eT;
+  
+  const Proxy<T1> P(X.m);
+  
+  const uword N = P.get_n_rows();
+  
+  arma_debug_check( (N != P.get_n_cols()), "det(): matrix is not square" );
+  
+  eT val1 = eT(1);
+  eT val2 = eT(1);
+  
+  uword i,j;
+  for(i=0, j=1; j<N; i+=2, j+=2)
+    {
+    val1 *= P.at(i,i);
+    val2 *= P.at(j,j);
+    }
+  
+  if(i < N)
+    {
+    val1 *= P.at(i,i);
+    }
+  
+  return val1 * val2;
   }
 
 
