@@ -88,4 +88,64 @@ var(const T&)
 
 
 
+template<typename T1>
+inline
+const mtSpOp<typename T1::pod_type, T1, spop_var>
+var
+  (
+  const T1& X,
+  const uword norm_type = 0,
+  const uword dim = 0,
+  const typename enable_if< is_arma_sparse_type<T1>::value       == true  >::result* junk1 = 0,
+  const typename enable_if< resolves_to_sparse_vector<T1>::value == false >::result* junk2 = 0
+  )
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(junk1);
+  arma_ignore(junk2);
+
+  return mtSpOp<typename T1::pod_type, T1, spop_var>(X, norm_type, dim);
+  }
+
+
+
+template<typename T1>
+inline
+const mtSpOp<typename T1::pod_type, T1, spop_var>
+var
+  (
+  const T1& X,
+  const uword norm_type,
+  const uword dim = 0,
+  const typename enable_if<resolves_to_sparse_vector<T1>::value == true>::result* junk1 = 0
+  )
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(junk1);
+
+  return mtSpOp<typename T1::pod_type, T1, spop_var>(X, norm_type, dim);
+  }
+
+
+
+template<typename T1>
+inline
+typename T1::pod_type
+var
+  (
+  const T1& X,
+  const uword norm_type = 0,
+  const arma_empty_class junk1 = arma_empty_class(),
+  const typename enable_if<resolves_to_sparse_vector<T1>::value == true>::result* junk2 = 0
+  )
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(junk1);
+  arma_ignore(junk2);
+
+  return spop_var::var_vec(X, norm_type);
+  }
+
+
+
 //! @}
