@@ -48,12 +48,11 @@ op_real::apply( Mat<typename T1::pod_type>& out, const mtOp<typename T1::pod_typ
     }
   else
     {
-    uword count = 0;
-    
     for(uword col=0; col < n_cols; ++col)
-    for(uword row=0; row < n_rows; ++row, ++count)
+    for(uword row=0; row < n_rows; ++row)
       {
-      out_mem[count] = std::real( P.at(row,col) );
+      *out_mem = std::real( P.at(row,col) );
+      out_mem++;
       }
     }
   }
@@ -69,16 +68,37 @@ op_real::apply( Cube<typename T1::pod_type>& out, const mtOpCube<typename T1::po
   
   typedef typename T1::pod_type T;
   
-  const ProxyCube<T1> A(X.m);
+  const ProxyCube<T1> P(X.m);
   
-  out.set_size(A.get_n_rows(), A.get_n_cols(), A.get_n_slices());
+  const uword n_rows   = P.get_n_rows();
+  const uword n_cols   = P.get_n_cols();
+  const uword n_slices = P.get_n_slices();
+    
+  out.set_size(n_rows, n_cols, n_slices);
   
-  const uword n_elem  = out.n_elem;
-        T*  out_mem = out.memptr();
-  
-  for(uword i=0; i<n_elem; ++i)
+  T* out_mem = out.memptr();
+
+  if(ProxyCube<T1>::prefer_at_accessor == false)
     {
-    out_mem[i] = std::real(A[i]);
+    typedef typename ProxyCube<T1>::ea_type ea_type;
+    
+    const uword   n_elem  = P.get_n_elem();
+          ea_type A       = P.get_ea();
+    
+    for(uword i=0; i < n_elem; ++i)
+      {
+      out_mem[i] = std::real( A[i] );
+      }
+    }
+  else
+    {
+    for(uword slice=0; slice < n_slices; ++slice)
+    for(uword col=0;   col   < n_cols;   ++col  )
+    for(uword row=0;   row   < n_rows;   ++row  )
+      {
+      *out_mem = std::real( P.at(row,col,slice) );
+      out_mem++;
+      }
     }
   }
 
@@ -116,12 +136,11 @@ op_imag::apply( Mat<typename T1::pod_type>& out, const mtOp<typename T1::pod_typ
     }
   else
     {
-    uword count = 0;
-    
     for(uword col=0; col < n_cols; ++col)
-    for(uword row=0; row < n_rows; ++row, ++count)
+    for(uword row=0; row < n_rows; ++row)
       {
-      out_mem[count] = std::imag( P.at(row,col) );
+      *out_mem = std::imag( P.at(row,col) );
+      out_mem++;
       }
     }
   }
@@ -137,16 +156,37 @@ op_imag::apply( Cube<typename T1::pod_type>& out, const mtOpCube<typename T1::po
   
   typedef typename T1::pod_type T;
   
-  const ProxyCube<T1> A(X.m);
+  const ProxyCube<T1> P(X.m);
   
-  out.set_size(A.get_n_rows(), A.get_n_cols(), A.get_n_slices());
+  const uword n_rows   = P.get_n_rows();
+  const uword n_cols   = P.get_n_cols();
+  const uword n_slices = P.get_n_slices();
+    
+  out.set_size(n_rows, n_cols, n_slices);
   
-  const uword n_elem  = out.n_elem;
-        T*  out_mem = out.memptr();
-  
-  for(uword i=0; i<n_elem; ++i)
+  T* out_mem = out.memptr();
+
+  if(ProxyCube<T1>::prefer_at_accessor == false)
     {
-    out_mem[i] = std::imag(A[i]);
+    typedef typename ProxyCube<T1>::ea_type ea_type;
+    
+    const uword   n_elem  = P.get_n_elem();
+          ea_type A       = P.get_ea();
+    
+    for(uword i=0; i < n_elem; ++i)
+      {
+      out_mem[i] = std::imag( A[i] );
+      }
+    }
+  else
+    {
+    for(uword slice=0; slice < n_slices; ++slice)
+    for(uword col=0;   col   < n_cols;   ++col  )
+    for(uword row=0;   row   < n_rows;   ++row  )
+      {
+      *out_mem = std::imag( P.at(row,col,slice) );
+      out_mem++;
+      }
     }
   }
 
@@ -184,12 +224,11 @@ op_abs::apply( Mat<typename T1::pod_type>& out, const mtOp<typename T1::pod_type
     }
   else
     {
-    uword count = 0;
-    
     for(uword col=0; col < n_cols; ++col)
-    for(uword row=0; row < n_rows; ++row, ++count)
+    for(uword row=0; row < n_rows; ++row)
       {
-      out_mem[count] = std::abs( P.at(row,col) );
+      *out_mem = std::abs( P.at(row,col) );
+      out_mem++;
       }
     }
   }
@@ -205,16 +244,37 @@ op_abs::apply( Cube<typename T1::pod_type>& out, const mtOpCube<typename T1::pod
   
   typedef typename T1::pod_type T;
   
-  const ProxyCube<T1> A(X.m);
+  const ProxyCube<T1> P(X.m);
   
-  out.set_size(A.get_n_rows(), A.get_n_cols(), A.get_n_slices());
+  const uword n_rows   = P.get_n_rows();
+  const uword n_cols   = P.get_n_cols();
+  const uword n_slices = P.get_n_slices();
+    
+  out.set_size(n_rows, n_cols, n_slices);
   
-  const uword n_elem  = out.n_elem;
-        T*  out_mem = out.memptr();
-  
-  for(uword i=0; i<n_elem; ++i)
+  T* out_mem = out.memptr();
+
+  if(ProxyCube<T1>::prefer_at_accessor == false)
     {
-    out_mem[i] = std::abs(A[i]);
+    typedef typename ProxyCube<T1>::ea_type ea_type;
+    
+    const uword   n_elem  = P.get_n_elem();
+          ea_type A       = P.get_ea();
+    
+    for(uword i=0; i < n_elem; ++i)
+      {
+      out_mem[i] = std::abs( A[i] );
+      }
+    }
+  else
+    {
+    for(uword slice=0; slice < n_slices; ++slice)
+    for(uword col=0;   col   < n_cols;   ++col  )
+    for(uword row=0;   row   < n_rows;   ++row  )
+      {
+      *out_mem = std::abs( P.at(row,col,slice) );
+      out_mem++;
+      }
     }
   }
 
