@@ -33,4 +33,35 @@ class spop_square
   };
 
 
+
+class spop_sqrt
+  {
+  public:
+  
+  template<typename T1>
+  arma_hot inline static void apply(SpMat<typename T1::elem_type>& out, const SpOp<T1, spop_sqrt>& in);
+  };
+
+
+
+class spop_abs
+  {
+  public:
+  
+  template<typename T1>
+  arma_hot inline static void apply(SpMat<typename T1::elem_type>& out, const SpOp<T1, spop_abs>& in);
+  };
+
+
+
+class spop_cx_abs
+  {
+  public:
+  
+  template<typename T1>
+  arma_hot inline static void apply(SpMat<typename T1::pod_type>& out, const mtSpOp<typename T1::pod_type, T1, spop_cx_abs>& in);
+  };
+
+
+
 //! @}
